@@ -31,6 +31,8 @@
 
 from __future__ import absolute_import, print_function
 
+import gi
+gi.require_version("Gtk", "3.0")
 from gi.repository import GLib
 from gi.repository import Gtk
 from gi.repository import Gdk
@@ -797,8 +799,8 @@ class UpdatesAvailable(InternalDialog):
                     self.button_pro.destroy()
                 elif (self.list.ubuntu_pro_fake_groups
                       and not self.list.ubuntu_pro_groups):
-                    download_str = _("You need to enable Ubuntu Pro to install"
-                                     " these updates.")
+                    download_str = _("You need to enable Ubuntu Pro to "
+                                     "install these updates.")
                     self.button_install.hide()
                 else:
                     download_str = _("There are no updates to install.")
